==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/cs_CZ.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Address book name" : "Název adresáře kontaktů",
    "Import" : "Importovat",
    "The selected image is too big (max 1MB)" : "Zvolený obrázek je příliš velký (max 1MB)",
    "No contacts in here" : "Nejsou zde žádné kontakty",
    "Name" : "Název",
    "Organization" : "Organizace",
    "Title" : "Název",
    "Add field ..." : "Přidat pole...",
    "Add contact" : "Přidat kontakt",
    "No search result for {query}" : "Žádný nález pro {query}",
    "All contacts" : "Všechny kontakty",
    "Not grouped" : "Neseskupené",
    "Post Office Box" : "Poštovní schránka",
    "Postal Code" : "Poštovní směrovací číslo",
    "City" : "Město",
    "State or province" : "Stát nebo provincie",
    "Country" : "Země",
    "Address" : "Adresa",
    "(new group)" : "(nová skupina)",
    "New contact" : "Nový kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} sdílí {owner}",
    "No contacts in file. Only VCard files are allowed." : "Žádné kontakty v souboru. Pouze soubory vCard jsou povoleny.",
    "Nickname" : "Přezdívka",
    "Notes" : "Poznámky",
    "Website" : "Stránka",
    "Federated Cloud ID" : "Sdružené cloud ID",
    "Home" : "Domů",
    "Work" : "Práce",
    "Other" : "Jiný",
    "Groups" : "Skupiny",
    "Birthday" : "Narozeniny",
    "Email" : "Email",
    "Instant messaging" : "Komunikátor",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax domů",
    "Fax work" : "Fax do práce",
    "Pager" : "Pager",
    "Voice" : "Hlas",
    "Social Network" : "Sociální síť",
    "Settings" : "Nastavení"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/cs_CZ.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Address book name" : "Název adresáře kontaktů",
    "Import" : "Importovat",
    "The selected image is too big (max 1MB)" : "Zvolený obrázek je příliš velký (max 1MB)",
    "No contacts in here" : "Nejsou zde žádné kontakty",
    "Name" : "Název",
    "Organization" : "Organizace",
    "Title" : "Název",
    "Add field ..." : "Přidat pole...",
    "+ New contact" : "+ Nový kontakt",
    "No search result for {query}" : "Žádný nález pro {query}",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakty","%n kontaktů"],
    "Post office box" : "Poštovní schránka",
    "Postal code" : "Směrovací číslo",
    "City" : "Město",
    "State or province" : "Stát nebo provincie",
    "Country" : "Země",
    "Address" : "Adresa",
    "(new group)" : "(nová skupina)",
    "Last name" : "Příjmení",
    "First name" : "Křestní jméno",
    "Additional names" : "Další jména",
    "Prefix" : "Předpona",
    "Suffix" : "Přípona",
    "All contacts" : "Všechny kontakty",
    "Not grouped" : "Neseskupené",
    "New contact" : "Nový kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} sdílí {owner}",
    "No contacts in file. Only VCard files are allowed." : "Žádné kontakty v souboru. Pouze soubory vCard jsou povoleny.",
    "Nickname" : "Přezdívka",
    "Detailed name" : "Jméno podrobně",
    "Notes" : "Poznámky",
    "Website" : "Stránka",
    "Federated Cloud ID" : "Sdružené cloud ID",
    "Home" : "Domů",
    "Work" : "Práce",
    "Other" : "Jiný",
    "Groups" : "Skupiny",
    "Birthday" : "Narozeniny",
    "Anniversary" : "Výročí",
    "Date of death" : "Datum úmrtí",
    "Email" : "Email",
    "Instant messaging" : "Komunikátor",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax domů",
    "Fax work" : "Fax do práce",
    "Pager" : "Pager",
    "Voice" : "Hlas",
    "Social network" : "Sociální síť",
    "Settings" : "Nastavení"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
